@@ -159,12 +159,15 @@ class TagManager(models.Manager):
         """
 
         if getattr(queryset.query, 'get_compiler', None):
-            # Django 1.2+
             compiler = queryset.query.get_compiler(using='default')
+            if getattr(compiler, 'compile', None):
+                # Django 1.7+
+                where, params = compiler.compile(queryset.query.where)
+            else:
+                # Django 1.2+
+                where, params = queryset.query.where.as_sql(
+                    compiler.quote_name_unless_alias, compiler.connection)
             extra_joins = ' '.join(compiler.get_from_clause()[0][1:])
-            where, params = queryset.query.where.as_sql(
-                compiler.quote_name_unless_alias, compiler.connection
-            )
         else:
             # Django pre-1.2
             extra_joins = ' '.join(queryset.query.get_from_clause()[0][1:])
